@@ -1,5 +1,5 @@
-__author__ = "Adam Tyson, Charly Rousseau"
-__version__ = "0.2.0"
+__author__ = "Charly Rousseau, Adam Tyson"
+__version__ = "0.2.1"
 
 from imio.load import *
 from imio.save import *
